@@ -1,8 +1,10 @@
 from configparser import DEFAULTSECT as default_section
-from configparser import ConfigParser
+from configparser import RawConfigParser
 from io import StringIO
+from json.decoder import JSONDecodeError
 
 from benedict.serializers.abstract import AbstractSerializer
+from benedict.serializers.json import JSONSerializer
 from benedict.utils import type_util
 
 
@@ -12,11 +14,20 @@ class INISerializer(AbstractSerializer):
     """
 
     def __init__(self):
-        super(INISerializer, self).__init__(
+        super().__init__(
             extensions=[
                 "ini",
             ],
         )
+        self._json = JSONSerializer()
+
+    @staticmethod
+    def _get_parser(options):
+        optionxform = options.pop("optionxform", lambda key: key)
+        parser = RawConfigParser(**options)
+        if optionxform and callable(optionxform):
+            parser.optionxform = optionxform
+        return parser
 
     @staticmethod
     def _get_section_option_value(parser, section, option):
@@ -31,7 +42,7 @@ class INISerializer(AbstractSerializer):
         return value
 
     def decode(self, s, **kwargs):
-        parser = ConfigParser(**kwargs)
+        parser = self._get_parser(options=kwargs)
         parser.read_string(s)
         data = {}
         for option, _ in parser.defaults().items():
@@ -41,13 +52,18 @@ class INISerializer(AbstractSerializer):
         for section in parser.sections():
             data[section] = {}
             for option, _ in parser.items(section):
-                data[section][option] = self._get_section_option_value(
-                    parser, section, option
-                )
+                value = self._get_section_option_value(parser, section, option)
+                if type_util.is_string(value):
+                    try:
+                        value_decoded = self._json.decode(value)
+                        value = value_decoded
+                    except JSONDecodeError:
+                        pass
+                data[section][option] = value
         return data
 
     def encode(self, d, **kwargs):
-        parser = ConfigParser(**kwargs)
+        parser = self._get_parser(options=kwargs)
         for key, value in d.items():
             if not type_util.is_dict(value):
                 parser.set(default_section, key, f"{value}")
@@ -55,7 +71,10 @@ class INISerializer(AbstractSerializer):
             section = key
             parser.add_section(section)
             for option_key, option_value in value.items():
-                parser.set(section, option_key, f"{option_value}")
+                if type_util.is_collection(option_value):
+                    parser.set(section, option_key, self._json.encode(option_value))
+                else:
+                    parser.set(section, option_key, option_value)
         str_data = StringIO()
         parser.write(str_data)
         return str_data.getvalue()
